@@ -4,7 +4,7 @@ use warnings;
 use parent qw/Plack::Middleware/;
 use Plack::App::File;
 
-use Plack::Util::Accessor qw( path root encoding pass_through );
+use Plack::Util::Accessor qw( path root encoding pass_through content_type );
 
 sub call {
     my $self = shift;
@@ -25,11 +25,11 @@ sub _handle_static {
     my $path = $env->{PATH_INFO};
 
     for ($path) {
-        my $matched = 'CODE' eq ref $path_match ? $path_match->($_) : $_ =~ $path_match;
+        my $matched = 'CODE' eq ref $path_match ? $path_match->($_, $env) : $_ =~ $path_match;
         return unless $matched;
     }
 
-    $self->{file} ||= Plack::App::File->new({ root => $self->root || '.', encoding => $self->encoding });
+    $self->{file} ||= Plack::App::File->new({ root => $self->root || '.', encoding => $self->encoding, content_type => $self->content_type });
     local $env->{PATH_INFO} = $path; # rewrite PATH
     return $self->{file}->call($env);
 }
@@ -67,7 +67,7 @@ If the requested document is not within the C<root> or the file is there but
 not readable, this middleware will return a 403 Forbidden response.
 
 The content type returned will be determined from the file extension by using
-L<Plack::MIME>.
+L<Plack::MIME> or using C<content_type>.
 
 =head1 CONFIGURATIONS
 
@@ -102,6 +102,10 @@ specified in the C<path> option matches against C<$_> munges this value using
 C<s///>. The subsitution operator returns the number of matches it made, so it
 will return true when the path matches C<^/static>.
 
+For more complex static handling in the C<path> callback, in addition
+to C<$_> being set the callback receives two arguments, C<PATH_INFO>
+(same as C<$_>) and C<$env>.
+
 If you want to map multiple static directories from different roots, simply
 add this middleware multiple times with different configuration options.
 
@@ -111,6 +115,15 @@ When this option is set to a true value, then this middleware will never
 return a 404 if it cannot find a matching file. Instead, it will simply pass
 the request on to the application it is wrapping.
 
+=item content_type
+
+The C<content_type> option can be used to provide access to a different MIME 
+database than L<Plack::MIME>.
+L<Plack::MIME> works fast and good for a list of well known file endings, 
+but if you need a more accurate content based checking you can use modules
+like L<File::MimeInfo> or L<File::MMagic> for example.
+The callback should work on $_[0] which is the filename of the file.
+
 =back
 
 =head1 AUTHOR
